@@ -106,7 +106,7 @@ newCommunityParams <- function(max_w = 1e6,
         z0 = z0, # background mortality
         alpha = alpha,
         erepro = 1, # not used
-        interaction_p = 1,
+        interaction_resource = 1,
         sel_func = "knife_edge",
         knife_edge_size = knife_edge_size,
         stringsAsFactors = FALSE
